from . import syntheticbuilding

def add_bad_data(data_container_array, gb_euclidean_distances_array_path = None, poisson_noise = None, poisson_vol_fraction = None, boundary_noise = None, boundary_vol_fraction = None, observer = None) -> int:
  """Pythonic interface to AddBadData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    gb_euclidean_distances_array_path (DataArrayPath): Sets the "GBEuclideanDistancesArrayPath" filter property
    poisson_noise (bool): Sets the "PoissonNoise" filter property
    poisson_vol_fraction (float): Sets the "PoissonVolFraction" filter property
    boundary_noise (bool): Sets the "BoundaryNoise" filter property
    boundary_vol_fraction (float): Sets the "BoundaryVolFraction" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.AddBadData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if gb_euclidean_distances_array_path is not None:
    filter.GBEuclideanDistancesArrayPath = gb_euclidean_distances_array_path
  if poisson_noise is not None:
    filter.PoissonNoise = poisson_noise
  if poisson_vol_fraction is not None:
    filter.PoissonVolFraction = poisson_vol_fraction
  if boundary_noise is not None:
    filter.BoundaryNoise = boundary_noise
  if boundary_vol_fraction is not None:
    filter.BoundaryVolFraction = boundary_vol_fraction
  filter.execute()
  return filter.ErrorCode

def add_orientation_noise(data_container_array, magnitude = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to AddOrientationNoise Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    magnitude (float): Sets the "Magnitude" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.AddOrientationNoise()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if magnitude is not None:
    filter.Magnitude = magnitude
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def establish_matrix_phase(data_container_array, output_cell_attribute_matrix_path = None, feature_ids_array_name = None, cell_phases_array_name = None, feature_phases_array_name = None, num_features_array_name = None, mask_array_path = None, use_mask = None, input_stats_array_path = None, input_phase_types_array_path = None, input_phase_names_array_path = None, observer = None) -> int:
  """Pythonic interface to EstablishMatrixPhase Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_cell_attribute_matrix_path (DataArrayPath): Sets the "OutputCellAttributeMatrixPath" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    cell_phases_array_name (QString): Sets the "CellPhasesArrayName" filter property
    feature_phases_array_name (QString): Sets the "FeaturePhasesArrayName" filter property
    num_features_array_name (QString): Sets the "NumFeaturesArrayName" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    input_phase_names_array_path (DataArrayPath): Sets the "InputPhaseNamesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.EstablishMatrixPhase()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_cell_attribute_matrix_path is not None:
    filter.OutputCellAttributeMatrixPath = output_cell_attribute_matrix_path
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if feature_phases_array_name is not None:
    filter.FeaturePhasesArrayName = feature_phases_array_name
  if num_features_array_name is not None:
    filter.NumFeaturesArrayName = num_features_array_name
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if input_phase_names_array_path is not None:
    filter.InputPhaseNamesArrayPath = input_phase_names_array_path
  filter.execute()
  return filter.ErrorCode

def establish_shape_types(data_container_array, input_phase_types_array_path = None, shape_types_array_name = None, shape_type_data = None, observer = None) -> int:
  """Pythonic interface to EstablishShapeTypes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    shape_types_array_name (QString): Sets the "ShapeTypesArrayName" filter property
    shape_type_data (ShapeType::Types): Sets the "ShapeTypeData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.EstablishShapeTypes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if shape_types_array_name is not None:
    filter.ShapeTypesArrayName = shape_types_array_name
  if shape_type_data is not None:
    filter.ShapeTypeData = shape_type_data
  filter.execute()
  return filter.ErrorCode

def initialize_synthetic_volume(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, ensemble_attribute_matrix_name = None, length_unit = None, dimensions = None, spacing = None, origin = None, input_stats_array_path = None, input_phase_types_array_path = None, input_phase_names_array_path = None, estimate_number_of_features = None, geometry_selection = None, geometry_data_container = None, observer = None) -> int:
  """Pythonic interface to InitializeSyntheticVolume Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    ensemble_attribute_matrix_name (QString): Sets the "EnsembleAttributeMatrixName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    dimensions (IntVec3Type): Sets the "Dimensions" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    input_phase_names_array_path (DataArrayPath): Sets the "InputPhaseNamesArrayPath" filter property
    estimate_number_of_features (bool): Sets the "EstimateNumberOfFeatures" filter property
    geometry_selection (int32_t): Sets the "GeometrySelection" filter property
    geometry_data_container (DataArrayPath): Sets the "GeometryDataContainer" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.InitializeSyntheticVolume()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if ensemble_attribute_matrix_name is not None:
    filter.EnsembleAttributeMatrixName = ensemble_attribute_matrix_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if dimensions is not None:
    filter.Dimensions = dimensions
  if spacing is not None:
    filter.Spacing = spacing
  if origin is not None:
    filter.Origin = origin
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if input_phase_names_array_path is not None:
    filter.InputPhaseNamesArrayPath = input_phase_names_array_path
  if estimate_number_of_features is not None:
    filter.EstimateNumberOfFeatures = estimate_number_of_features
  if geometry_selection is not None:
    filter.GeometrySelection = geometry_selection
  if geometry_data_container is not None:
    filter.GeometryDataContainer = geometry_data_container
  filter.execute()
  return filter.ErrorCode

def insert_atoms(data_container_array, vertex_data_container_name = None, vertex_attribute_matrix_name = None, lattice_constants = None, basis = None, surface_mesh_face_labels_array_path = None, avg_quats_array_path = None, atom_feature_labels_array_name = None, observer = None) -> int:
  """Pythonic interface to InsertAtoms Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    vertex_data_container_name (DataArrayPath): Sets the "VertexDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    lattice_constants (FloatVec3Type): Sets the "LatticeConstants" filter property
    basis (int): Sets the "Basis" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    atom_feature_labels_array_name (QString): Sets the "AtomFeatureLabelsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.InsertAtoms()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if vertex_data_container_name is not None:
    filter.VertexDataContainerName = vertex_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if lattice_constants is not None:
    filter.LatticeConstants = lattice_constants
  if basis is not None:
    filter.Basis = basis
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if atom_feature_labels_array_name is not None:
    filter.AtomFeatureLabelsArrayName = atom_feature_labels_array_name
  filter.execute()
  return filter.ErrorCode

def insert_precipitate_phases(data_container_array, csv_output_file = None, mask_array_path = None, use_mask = None, feature_generation = None, precip_input_file = None, periodic_boundaries = None, match_rdf = None, write_goal_attributes = None, input_stats_array_path = None, input_phase_types_array_path = None, input_shape_types_array_path = None, feature_ids_array_path = None, cell_phases_array_path = None, boundary_cells_array_path = None, feature_phases_array_path = None, num_cells_array_name = None, equivalent_diameters_array_name = None, volumes_array_name = None, omega3s_array_name = None, centroids_array_name = None, axis_euler_angles_array_name = None, axis_lengths_array_name = None, num_features_array_path = None, save_geometric_descriptions = None, new_attribute_matrix_path = None, selected_attribute_matrix_path = None, observer = None) -> int:
  """Pythonic interface to InsertPrecipitatePhases Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    csv_output_file (QString): Sets the "CsvOutputFile" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    feature_generation (int): Sets the "FeatureGeneration" filter property
    precip_input_file (QString): Sets the "PrecipInputFile" filter property
    periodic_boundaries (bool): Sets the "PeriodicBoundaries" filter property
    match_rdf (bool): Sets the "MatchRDF" filter property
    write_goal_attributes (bool): Sets the "WriteGoalAttributes" filter property
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    input_shape_types_array_path (DataArrayPath): Sets the "InputShapeTypesArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    boundary_cells_array_path (DataArrayPath): Sets the "BoundaryCellsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    num_cells_array_name (QString): Sets the "NumCellsArrayName" filter property
    equivalent_diameters_array_name (QString): Sets the "EquivalentDiametersArrayName" filter property
    volumes_array_name (QString): Sets the "VolumesArrayName" filter property
    omega3s_array_name (QString): Sets the "Omega3sArrayName" filter property
    centroids_array_name (QString): Sets the "CentroidsArrayName" filter property
    axis_euler_angles_array_name (QString): Sets the "AxisEulerAnglesArrayName" filter property
    axis_lengths_array_name (QString): Sets the "AxisLengthsArrayName" filter property
    num_features_array_path (DataArrayPath): Sets the "NumFeaturesArrayPath" filter property
    save_geometric_descriptions (int): Sets the "SaveGeometricDescriptions" filter property
    new_attribute_matrix_path (DataArrayPath): Sets the "NewAttributeMatrixPath" filter property
    selected_attribute_matrix_path (DataArrayPath): Sets the "SelectedAttributeMatrixPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.InsertPrecipitatePhases()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if csv_output_file is not None:
    filter.CsvOutputFile = csv_output_file
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if feature_generation is not None:
    filter.FeatureGeneration = feature_generation
  if precip_input_file is not None:
    filter.PrecipInputFile = precip_input_file
  if periodic_boundaries is not None:
    filter.PeriodicBoundaries = periodic_boundaries
  if match_rdf is not None:
    filter.MatchRDF = match_rdf
  if write_goal_attributes is not None:
    filter.WriteGoalAttributes = write_goal_attributes
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if input_shape_types_array_path is not None:
    filter.InputShapeTypesArrayPath = input_shape_types_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if boundary_cells_array_path is not None:
    filter.BoundaryCellsArrayPath = boundary_cells_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if num_cells_array_name is not None:
    filter.NumCellsArrayName = num_cells_array_name
  if equivalent_diameters_array_name is not None:
    filter.EquivalentDiametersArrayName = equivalent_diameters_array_name
  if volumes_array_name is not None:
    filter.VolumesArrayName = volumes_array_name
  if omega3s_array_name is not None:
    filter.Omega3sArrayName = omega3s_array_name
  if centroids_array_name is not None:
    filter.CentroidsArrayName = centroids_array_name
  if axis_euler_angles_array_name is not None:
    filter.AxisEulerAnglesArrayName = axis_euler_angles_array_name
  if axis_lengths_array_name is not None:
    filter.AxisLengthsArrayName = axis_lengths_array_name
  if num_features_array_path is not None:
    filter.NumFeaturesArrayPath = num_features_array_path
  if save_geometric_descriptions is not None:
    filter.SaveGeometricDescriptions = save_geometric_descriptions
  if new_attribute_matrix_path is not None:
    filter.NewAttributeMatrixPath = new_attribute_matrix_path
  if selected_attribute_matrix_path is not None:
    filter.SelectedAttributeMatrixPath = selected_attribute_matrix_path
  filter.execute()
  return filter.ErrorCode

def jumble_orientations(data_container_array, feature_ids_array_path = None, cell_euler_angles_array_name = None, feature_phases_array_path = None, feature_euler_angles_array_path = None, avg_quats_array_name = None, observer = None) -> int:
  """Pythonic interface to JumbleOrientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_euler_angles_array_name (QString): Sets the "CellEulerAnglesArrayName" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    avg_quats_array_name (QString): Sets the "AvgQuatsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.JumbleOrientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_euler_angles_array_name is not None:
    filter.CellEulerAnglesArrayName = cell_euler_angles_array_name
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if avg_quats_array_name is not None:
    filter.AvgQuatsArrayName = avg_quats_array_name
  filter.execute()
  return filter.ErrorCode

def match_crystallography(data_container_array, input_stats_array_path = None, crystal_structures_array_path = None, phase_types_array_path = None, feature_ids_array_path = None, feature_phases_array_path = None, surface_features_array_path = None, neighbor_list_array_path = None, shared_surface_area_list_array_path = None, num_features_array_path = None, cell_euler_angles_array_name = None, volumes_array_name = None, feature_euler_angles_array_name = None, avg_quats_array_name = None, max_iterations = None, observer = None) -> int:
  """Pythonic interface to MatchCrystallography Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    phase_types_array_path (DataArrayPath): Sets the "PhaseTypesArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    surface_features_array_path (DataArrayPath): Sets the "SurfaceFeaturesArrayPath" filter property
    neighbor_list_array_path (DataArrayPath): Sets the "NeighborListArrayPath" filter property
    shared_surface_area_list_array_path (DataArrayPath): Sets the "SharedSurfaceAreaListArrayPath" filter property
    num_features_array_path (DataArrayPath): Sets the "NumFeaturesArrayPath" filter property
    cell_euler_angles_array_name (QString): Sets the "CellEulerAnglesArrayName" filter property
    volumes_array_name (QString): Sets the "VolumesArrayName" filter property
    feature_euler_angles_array_name (QString): Sets the "FeatureEulerAnglesArrayName" filter property
    avg_quats_array_name (QString): Sets the "AvgQuatsArrayName" filter property
    max_iterations (int): Sets the "MaxIterations" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.MatchCrystallography()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if phase_types_array_path is not None:
    filter.PhaseTypesArrayPath = phase_types_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if surface_features_array_path is not None:
    filter.SurfaceFeaturesArrayPath = surface_features_array_path
  if neighbor_list_array_path is not None:
    filter.NeighborListArrayPath = neighbor_list_array_path
  if shared_surface_area_list_array_path is not None:
    filter.SharedSurfaceAreaListArrayPath = shared_surface_area_list_array_path
  if num_features_array_path is not None:
    filter.NumFeaturesArrayPath = num_features_array_path
  if cell_euler_angles_array_name is not None:
    filter.CellEulerAnglesArrayName = cell_euler_angles_array_name
  if volumes_array_name is not None:
    filter.VolumesArrayName = volumes_array_name
  if feature_euler_angles_array_name is not None:
    filter.FeatureEulerAnglesArrayName = feature_euler_angles_array_name
  if avg_quats_array_name is not None:
    filter.AvgQuatsArrayName = avg_quats_array_name
  if max_iterations is not None:
    filter.MaxIterations = max_iterations
  filter.execute()
  return filter.ErrorCode

def pack_primary_phases(data_container_array, output_cell_attribute_matrix_path = None, output_cell_feature_attribute_matrix_name = None, output_cell_ensemble_attribute_matrix_name = None, feature_ids_array_name = None, cell_phases_array_name = None, feature_phases_array_name = None, num_features_array_name = None, input_stats_array_path = None, input_phase_types_array_path = None, input_phase_names_array_path = None, input_shape_types_array_path = None, mask_array_path = None, use_mask = None, feature_generation = None, feature_input_file = None, csv_output_file = None, periodic_boundaries = None, write_goal_attributes = None, save_geometric_descriptions = None, new_attribute_matrix_path = None, selected_attribute_matrix_path = None, observer = None) -> int:
  """Pythonic interface to PackPrimaryPhases Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_cell_attribute_matrix_path (DataArrayPath): Sets the "OutputCellAttributeMatrixPath" filter property
    output_cell_feature_attribute_matrix_name (QString): Sets the "OutputCellFeatureAttributeMatrixName" filter property
    output_cell_ensemble_attribute_matrix_name (QString): Sets the "OutputCellEnsembleAttributeMatrixName" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    cell_phases_array_name (QString): Sets the "CellPhasesArrayName" filter property
    feature_phases_array_name (QString): Sets the "FeaturePhasesArrayName" filter property
    num_features_array_name (QString): Sets the "NumFeaturesArrayName" filter property
    input_stats_array_path (DataArrayPath): Sets the "InputStatsArrayPath" filter property
    input_phase_types_array_path (DataArrayPath): Sets the "InputPhaseTypesArrayPath" filter property
    input_phase_names_array_path (DataArrayPath): Sets the "InputPhaseNamesArrayPath" filter property
    input_shape_types_array_path (DataArrayPath): Sets the "InputShapeTypesArrayPath" filter property
    mask_array_path (DataArrayPath): Sets the "MaskArrayPath" filter property
    use_mask (bool): Sets the "UseMask" filter property
    feature_generation (int): Sets the "FeatureGeneration" filter property
    feature_input_file (QString): Sets the "FeatureInputFile" filter property
    csv_output_file (QString): Sets the "CsvOutputFile" filter property
    periodic_boundaries (bool): Sets the "PeriodicBoundaries" filter property
    write_goal_attributes (bool): Sets the "WriteGoalAttributes" filter property
    save_geometric_descriptions (int): Sets the "SaveGeometricDescriptions" filter property
    new_attribute_matrix_path (DataArrayPath): Sets the "NewAttributeMatrixPath" filter property
    selected_attribute_matrix_path (DataArrayPath): Sets the "SelectedAttributeMatrixPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.PackPrimaryPhases()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_cell_attribute_matrix_path is not None:
    filter.OutputCellAttributeMatrixPath = output_cell_attribute_matrix_path
  if output_cell_feature_attribute_matrix_name is not None:
    filter.OutputCellFeatureAttributeMatrixName = output_cell_feature_attribute_matrix_name
  if output_cell_ensemble_attribute_matrix_name is not None:
    filter.OutputCellEnsembleAttributeMatrixName = output_cell_ensemble_attribute_matrix_name
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  if cell_phases_array_name is not None:
    filter.CellPhasesArrayName = cell_phases_array_name
  if feature_phases_array_name is not None:
    filter.FeaturePhasesArrayName = feature_phases_array_name
  if num_features_array_name is not None:
    filter.NumFeaturesArrayName = num_features_array_name
  if input_stats_array_path is not None:
    filter.InputStatsArrayPath = input_stats_array_path
  if input_phase_types_array_path is not None:
    filter.InputPhaseTypesArrayPath = input_phase_types_array_path
  if input_phase_names_array_path is not None:
    filter.InputPhaseNamesArrayPath = input_phase_names_array_path
  if input_shape_types_array_path is not None:
    filter.InputShapeTypesArrayPath = input_shape_types_array_path
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  if use_mask is not None:
    filter.UseMask = use_mask
  if feature_generation is not None:
    filter.FeatureGeneration = feature_generation
  if feature_input_file is not None:
    filter.FeatureInputFile = feature_input_file
  if csv_output_file is not None:
    filter.CsvOutputFile = csv_output_file
  if periodic_boundaries is not None:
    filter.PeriodicBoundaries = periodic_boundaries
  if write_goal_attributes is not None:
    filter.WriteGoalAttributes = write_goal_attributes
  if save_geometric_descriptions is not None:
    filter.SaveGeometricDescriptions = save_geometric_descriptions
  if new_attribute_matrix_path is not None:
    filter.NewAttributeMatrixPath = new_attribute_matrix_path
  if selected_attribute_matrix_path is not None:
    filter.SelectedAttributeMatrixPath = selected_attribute_matrix_path
  filter.execute()
  return filter.ErrorCode

def stats_generator_filter(data_container_array, stats_generator_data_container_name = None, cell_ensemble_attribute_matrix_name = None, stats_data_array_name = None, crystal_structures_array_name = None, phase_types_array_name = None, phase_names_array_name = None, stats_data_array = None, crystal_structures = None, phase_types = None, phase_names = None, path = None, observer = None) -> int:
  """Pythonic interface to StatsGeneratorFilter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    stats_generator_data_container_name (DataArrayPath): Sets the "StatsGeneratorDataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    stats_data_array_name (QString): Sets the "StatsDataArrayName" filter property
    crystal_structures_array_name (QString): Sets the "CrystalStructuresArrayName" filter property
    phase_types_array_name (QString): Sets the "PhaseTypesArrayName" filter property
    phase_names_array_name (QString): Sets the "PhaseNamesArrayName" filter property
    stats_data_array (StatsDataArray::Pointer): Sets the "StatsDataArray" filter property
    crystal_structures (UInt32ArrayType::Pointer): Sets the "CrystalStructures" filter property
    phase_types (UInt32ArrayType::Pointer): Sets the "PhaseTypes" filter property
    phase_names (StringDataArray::Pointer): Sets the "PhaseNames" filter property
    path (DataArrayPath): Sets the "Path" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.StatsGeneratorFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if stats_generator_data_container_name is not None:
    filter.StatsGeneratorDataContainerName = stats_generator_data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if stats_data_array_name is not None:
    filter.StatsDataArrayName = stats_data_array_name
  if crystal_structures_array_name is not None:
    filter.CrystalStructuresArrayName = crystal_structures_array_name
  if phase_types_array_name is not None:
    filter.PhaseTypesArrayName = phase_types_array_name
  if phase_names_array_name is not None:
    filter.PhaseNamesArrayName = phase_names_array_name
  if stats_data_array is not None:
    filter.StatsDataArray = stats_data_array
  if crystal_structures is not None:
    filter.CrystalStructures = crystal_structures
  if phase_types is not None:
    filter.PhaseTypes = phase_types
  if phase_names is not None:
    filter.PhaseNames = phase_names
  if path is not None:
    filter.Path = path
  filter.execute()
  return filter.ErrorCode

def generate_primary_stats_data(data_container_array, phase_name = None, phase_index = None, crystal_symmetry = None, micro_preset_model = None, phase_fraction = None, mu = None, sigma = None, min_cut_off = None, max_cut_off = None, bin_step_size = None, create_ensemble_attribute_matrix = None, data_container_name = None, cell_ensemble_attribute_matrix_name = None, append_to_existing_attribute_matrix = None, selected_ensemble_attribute_matrix = None, odf_data = None, mdf_data = None, axis_odf_data = None, observer = None) -> int:
  """Pythonic interface to GeneratePrimaryStatsData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    phase_name (QString): Sets the "PhaseName" filter property
    phase_index (int): Sets the "PhaseIndex" filter property
    crystal_symmetry (int): Sets the "CrystalSymmetry" filter property
    micro_preset_model (int): Sets the "MicroPresetModel" filter property
    phase_fraction (double): Sets the "PhaseFraction" filter property
    mu (double): Sets the "Mu" filter property
    sigma (double): Sets the "Sigma" filter property
    min_cut_off (double): Sets the "MinCutOff" filter property
    max_cut_off (double): Sets the "MaxCutOff" filter property
    bin_step_size (double): Sets the "BinStepSize" filter property
    create_ensemble_attribute_matrix (bool): Sets the "CreateEnsembleAttributeMatrix" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    append_to_existing_attribute_matrix (bool): Sets the "AppendToExistingAttributeMatrix" filter property
    selected_ensemble_attribute_matrix (DataArrayPath): Sets the "SelectedEnsembleAttributeMatrix" filter property
    odf_data (DynamicTableData): Sets the "OdfData" filter property
    mdf_data (DynamicTableData): Sets the "MdfData" filter property
    axis_odf_data (DynamicTableData): Sets the "AxisOdfData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.GeneratePrimaryStatsData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if phase_name is not None:
    filter.PhaseName = phase_name
  if phase_index is not None:
    filter.PhaseIndex = phase_index
  if crystal_symmetry is not None:
    filter.CrystalSymmetry = crystal_symmetry
  if micro_preset_model is not None:
    filter.MicroPresetModel = micro_preset_model
  if phase_fraction is not None:
    filter.PhaseFraction = phase_fraction
  if mu is not None:
    filter.Mu = mu
  if sigma is not None:
    filter.Sigma = sigma
  if min_cut_off is not None:
    filter.MinCutOff = min_cut_off
  if max_cut_off is not None:
    filter.MaxCutOff = max_cut_off
  if bin_step_size is not None:
    filter.BinStepSize = bin_step_size
  if create_ensemble_attribute_matrix is not None:
    filter.CreateEnsembleAttributeMatrix = create_ensemble_attribute_matrix
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if append_to_existing_attribute_matrix is not None:
    filter.AppendToExistingAttributeMatrix = append_to_existing_attribute_matrix
  if selected_ensemble_attribute_matrix is not None:
    filter.SelectedEnsembleAttributeMatrix = selected_ensemble_attribute_matrix
  if odf_data is not None:
    filter.OdfData = odf_data
  if mdf_data is not None:
    filter.MdfData = mdf_data
  if axis_odf_data is not None:
    filter.AxisOdfData = axis_odf_data
  filter.execute()
  return filter.ErrorCode

def generate_precipitate_stats_data(data_container_array, phase_name = None, phase_index = None, crystal_symmetry = None, micro_preset_model = None, phase_fraction = None, mu = None, sigma = None, min_cut_off = None, max_cut_off = None, bin_step_size = None, create_ensemble_attribute_matrix = None, data_container_name = None, cell_ensemble_attribute_matrix_name = None, append_to_existing_attribute_matrix = None, selected_ensemble_attribute_matrix = None, odf_data = None, mdf_data = None, axis_odf_data = None, rdf_min_max_distance = None, rdf_num_bins = None, rdf_box_size = None, observer = None) -> int:
  """Pythonic interface to GeneratePrecipitateStatsData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    phase_name (QString): Sets the "PhaseName" filter property
    phase_index (int): Sets the "PhaseIndex" filter property
    crystal_symmetry (int): Sets the "CrystalSymmetry" filter property
    micro_preset_model (int): Sets the "MicroPresetModel" filter property
    phase_fraction (double): Sets the "PhaseFraction" filter property
    mu (double): Sets the "Mu" filter property
    sigma (double): Sets the "Sigma" filter property
    min_cut_off (double): Sets the "MinCutOff" filter property
    max_cut_off (double): Sets the "MaxCutOff" filter property
    bin_step_size (double): Sets the "BinStepSize" filter property
    create_ensemble_attribute_matrix (bool): Sets the "CreateEnsembleAttributeMatrix" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    append_to_existing_attribute_matrix (bool): Sets the "AppendToExistingAttributeMatrix" filter property
    selected_ensemble_attribute_matrix (DataArrayPath): Sets the "SelectedEnsembleAttributeMatrix" filter property
    odf_data (DynamicTableData): Sets the "OdfData" filter property
    mdf_data (DynamicTableData): Sets the "MdfData" filter property
    axis_odf_data (DynamicTableData): Sets the "AxisOdfData" filter property
    rdf_min_max_distance (FloatVec2Type): Sets the "RdfMinMaxDistance" filter property
    rdf_num_bins (int): Sets the "RdfNumBins" filter property
    rdf_box_size (FloatVec3Type): Sets the "RdfBoxSize" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = syntheticbuilding.GeneratePrecipitateStatsData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if phase_name is not None:
    filter.PhaseName = phase_name
  if phase_index is not None:
    filter.PhaseIndex = phase_index
  if crystal_symmetry is not None:
    filter.CrystalSymmetry = crystal_symmetry
  if micro_preset_model is not None:
    filter.MicroPresetModel = micro_preset_model
  if phase_fraction is not None:
    filter.PhaseFraction = phase_fraction
  if mu is not None:
    filter.Mu = mu
  if sigma is not None:
    filter.Sigma = sigma
  if min_cut_off is not None:
    filter.MinCutOff = min_cut_off
  if max_cut_off is not None:
    filter.MaxCutOff = max_cut_off
  if bin_step_size is not None:
    filter.BinStepSize = bin_step_size
  if create_ensemble_attribute_matrix is not None:
    filter.CreateEnsembleAttributeMatrix = create_ensemble_attribute_matrix
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if append_to_existing_attribute_matrix is not None:
    filter.AppendToExistingAttributeMatrix = append_to_existing_attribute_matrix
  if selected_ensemble_attribute_matrix is not None:
    filter.SelectedEnsembleAttributeMatrix = selected_ensemble_attribute_matrix
  if odf_data is not None:
    filter.OdfData = odf_data
  if mdf_data is not None:
    filter.MdfData = mdf_data
  if axis_odf_data is not None:
    filter.AxisOdfData = axis_odf_data
  if rdf_min_max_distance is not None:
    filter.RdfMinMaxDistance = rdf_min_max_distance
  if rdf_num_bins is not None:
    filter.RdfNumBins = rdf_num_bins
  if rdf_box_size is not None:
    filter.RdfBoxSize = rdf_box_size
  filter.execute()
  return filter.ErrorCode

